@@ -9,8 +9,8 @@
 SEXP R_crossprod_spm(SEXP x)
 {
   SEXP ret;
-  const len_t m = NROWS(x);
-  const len_t n = NCOLS(x);
+  const float_len_t m = NROWS(x);
+  const float_len_t n = NCOLS(x);
   
   PROTECT(ret = newmat(n, n));
   
@@ -40,8 +40,8 @@ SEXP R_crossprod_spmspm(SEXP x, SEXP y)
 SEXP R_tcrossprod_spm(SEXP x)
 {
   SEXP ret;
-  const len_t m = NROWS(x);
-  const len_t n = NCOLS(x);
+  const float_len_t m = NROWS(x);
+  const float_len_t n = NCOLS(x);
   
   PROTECT(ret = newmat(m, m));
   
